@@ -238,10 +238,18 @@ function do_action(){
       run "Push tags"    git push --tags
     ;;
 
+    check-clean)
+        run "Checking what would be removed with clean" git clean -xdn -e '*venv*/' -e op.log
+    ;;
+
     clean)
         run "Removing built files but preserving venv" git clean -xdf -e '*venv*/' -e op.log
     ;;
 
+    check-clean-all)
+        run "Checking what would be removed with clean-all" git clean -xdn -e op.log
+    ;;
+
     clean-all)
         run "Removing built files and venv" git clean -xdf -e op.log
     ;;
