@@ -7,17 +7,23 @@
 # ------------------------------------------------------------------------------------------------------------------------
 # Import and pathing setup
 # ------------------------------------------------------------------------------------------------------------------------
+import errno
 import os
 import sys
 import pathlib
-from typing import Any, Callable, Dict, Generator, Iterable, Optional, Pattern, Union
+from typing import Any, Callable, Dict, Generator, Iterable, Optional, Pattern, Tuple, Union
 
 from ptutils.io import get_loader, get_saver, load_txt, save_txt
 from ptutils.encoding import HAVE_YAML, register_yaml_type
 from ptutils.globbing import get_subdirs, get_subfiles
 from ptutils.text import strip_line_ending
 from ptutils.undefined import UNDEFINED, is_defined
+from ptutils.typing import MutableMapping
 
+# ------------------------------------------------------------------------------------------------------------------------
+# Globals
+# ------------------------------------------------------------------------------------------------------------------------
+FOLDER_STORE_DEFAULT_SUFFIX = "yml" if HAVE_YAML else "json"
 
 # ------------------------------------------------------------------------------------------------------------------------
 # Typehint helpers
@@ -752,6 +758,211 @@ class FolderSet:
         )
 
 
+# -----------------------------------------------------------------------------------------------------------------------
+# class: FolderStore
+# -----------------------------------------------------------------------------------------------------------------------
+class FolderStore(MutableMapping):
+    """
+    An adapter class to use mapping-style access to a folder of datafiles. Mapping indices
+    are the stem of the filenames, with suffix being either 'yml', 'json', or other formats
+    for which encoding are supported.
+
+    """
+    def __init__(self, folder: Folder, suffix=FOLDER_STORE_DEFAULT_SUFFIX):
+        """
+        Create a folder store.
+
+        Parameters
+        ----------
+        folder : Folder
+            The path to the filesystem location where data files will be kept.
+        suffix : str, optional
+            The filename extension to use, by default "yml" if YAML support is available, else "json". Supported formats
+            are the same as for `File.content`.
+
+        Raises
+        ------
+        ValueError
+            If the path is a protected path path (e.g. '/').
+        """
+        if suffix not in ["yaml", "yml", "json"]:
+            raise ValueError(f"Suffix is not a supported format ('yml', 'yaml', or 'json'): '{suffix}'")
+        self.folder  = Folder(Folder(folder).absolute())
+        self.suffix  = suffix
+        self.pattern = r"^.*\." + suffix + r"$"
+        self.template = "{name}." + suffix
+        if str(self.folder) == "/":
+            raise ValueError("Can't create a cache at the root path '/'.")
+        self._create_folder()
+
+    def _create_folder(self) -> None:
+        """
+        Create the backing folder.
+
+        Raises
+        ------
+        Exception
+            When the backing folder does not already exist and can not be created.
+        """
+        try:
+            self.folder.mkdir(parents=True, exist_ok=True)
+        except Exception as e:
+            raise Exception(f"Failed to create cache directory: {e}") from e
+
+    def _destroy_folder(self) -> None:
+        """
+        Destroy the backing folder and delete all contents.
+
+        Raises
+        ------
+        Exception
+            When removal of the directory fails.
+        """
+        try:
+            from shutil import rmtree
+            rmtree(str(self.folder))
+        except Exception as e:
+            raise Exception(f"Failed to destroy cache directory: {e}") from e
+
+    def clear(self) -> None:
+        """
+        Clear all folder contents.
+        """
+        self._destroy_folder()
+        self._create_folder()
+
+    def get_datafile(self, name: str, ensure_exists: bool = False) -> File:
+        """
+        get the backing `File` object corresponding to the supplied `name`.
+
+        Parameters
+        ----------
+        name : str
+            The name of the file. Must be a valid filename component.
+        ensure_exists : bool, optional
+            When true check if the file exists already and raise FileNotFoundError
+            if missing, by default False
+
+        Returns
+        -------
+        File
+            A file object corresponding to the given `name`.
+
+        Raises
+        ------
+        FileNotFoundError
+            When `ensure_exists` is true but the file does not exist.
+        """
+        rv = self.folder.child_file( self.template.format(name = name) )
+        if ensure_exists and not rv.exists():
+            raise FileNotFoundError(errno.ENOENT, os.strerror(errno.ENOENT), str(rv))
+        return rv
+
+    @property
+    def files(self) -> Generator[File, None, None]:
+        """
+        An iterable over all files in the backing folder matching the store's filename pattern.
+
+        Returns
+        -------
+        Iterable[File]
+            The matching files.
+        """
+        return self.folder.search_files(pattern=self.pattern, recursive=False)
+
+    def __getitem__(self, name: str) -> Any:
+        """
+        Get a file-backed item value corresponding to the supplied `name`.
+
+        Parameters
+        ----------
+        name : str
+            The name of the value.
+
+        Returns
+        -------
+        Any
+            The value.
+
+        Raises
+        ------
+        KeyError
+            When the backing file does not exist.
+        """
+        try:
+            return self.get_datafile(name, ensure_exists=True).content
+        except Exception as e:
+            raise KeyError(name) from e
+
+    def __setitem__(self, name: str, value: Any) -> None:
+        """
+        Set the file-backed item value corresponding to the supplied `name`.
+
+        Parameters
+        ----------
+        name : str
+            The name.
+        value : Any
+            The new value.
+        """
+        self.get_datafile(name, ensure_exists=False).content = value
+
+    def __delitem__(self, name: str) -> None:
+        """
+        Remove the file-backed item value corresponding to the supplied `name`.
+
+        Parameters
+        ----------
+        name : str
+            The name.
+
+        Raises
+        ------
+        KeyError
+            When the backing file does not exist.
+        """
+        try:
+            file = self.get_datafile(name, ensure_exists=True)
+        except FileNotFoundError as e:
+            raise KeyError(name) from e
+        file.unlink()
+
+    def __iter__(self) -> Generator[str, None, None]:
+        """
+        Iterate over names of the file-backed store.
+
+        Yields
+        ------
+        str
+            The names of the values.
+        """
+        for file in self.files:
+            yield str(file.stem)
+
+    def __len__(self) -> int:
+        """
+        Return the count of items in the store.
+
+        Returns
+        -------
+        int
+            The count of files in the backing directory which match the naming pattern.
+        """
+        return sum( 1 for _ in iter( self ) )
+
+    def items(self) -> Generator[ Tuple[str, Any], None, None ]:
+        """
+        Iterator over key-value pairs.
+
+        Yields
+        ------
+        Tuple[str, Any]
+            key-value pairs.
+        """
+        for file in self.files:
+            yield str(file.stem), file.content
+
+
 # =======================================================================================================================
 # Helpers: yaml encoding/decoding of file/folder/path classes
 # =======================================================================================================================
