@@ -14,7 +14,7 @@ from ptutils.undefined import default_if_undefined, UNDEFINED, Undefined
 # Logger config
 # ------------------------------------------------------------------------------------------------------------------------
 """ The default verbosity to use when not otherwise specified."""
-DEFAULT_VERBOSITY = 2
+DEFAULT_VERBOSITY = 3
 
 
 """ The currently configured verbosity. use `get_verbosity` or `set_verbosity` to modify. """
@@ -34,12 +34,12 @@ __LEVEL_NAME__ = 'INFO'
 # ------------------------------------------------------------------------------------------------------------------------
 """ A mapping between verbosity levels and standard python logging levels. """
 __VERBOSITY_LEVELS__: Dict[int, Tuple[int, str]] = {
-    0: (logging.NOTSET + 1, "VERBOSE"),
-    1: (logging.DEBUG,      "DEBUG"),
-    2: (logging.INFO,       "INFO"),
-    3: (logging.WARNING,    "WARNING"),
-    4: (logging.ERROR,      "ERROR"),
-    5: (logging.CRITICAL,   "CRITICAL")
+    5: (logging.NOTSET + 1, "VERBOSE"),
+    4: (logging.DEBUG,      "DEBUG"),
+    3: (logging.INFO,       "INFO"),
+    2: (logging.WARNING,    "WARNING"),
+    1: (logging.ERROR,      "ERROR"),
+    0: (logging.CRITICAL,   "CRITICAL")
 }
 
 
@@ -125,9 +125,9 @@ def set_verbosity(verbosity: Union[int, Undefined] = UNDEFINED) -> None:  # prag
     verbosity = clip_verbosity_level(verbosity)
 
     # translate verbosity to log level
-    level, _  = translate_verbosity_level(verbosity)
+    level, name = translate_verbosity_level(verbosity)
 
-    level, name = translate_verbosity_level(__VERBOSITY__)
+    # apply verbosity level
     logger.setLevel(level)
     __VERBOSITY__  = verbosity
     __LEVEL__      = level
