@@ -3,14 +3,17 @@
 
 """This module provides unit tests for `ptutils.file`."""
 
+import datetime
 import os
+import shutil
 import sys
+import tempfile
 import pytest
 import pathlib
-from ptutils.file import ( Path, File, Folder, FolderSet )
+from ptutils.file import ( FolderStore, Path, File, Folder, FolderSet )
 from ptutils.undefined import UNDEFINED, is_defined
-from ptutils.encoding import decode_json, decode_yaml, encode_json
-from ptutils.io import load_txt, load_json, load_yaml, save_txt, save_json, save_yaml
+from ptutils.encoding import HAVE_YAML, decode_json, decode_yaml, encode_json
+from ptutils.io import load, load_txt, load_json, load_yaml, save, save_txt, save_json, save_yaml
 from ._fs_fixture import sample_file_structure  # noqa: F401
 from ._fs_fixture import FILE_STRUCTURE
 from ._fs_fixture import localize_path
@@ -522,3 +525,136 @@ def test_folderset_structured(sample_file_structure):  # noqa: F811
     f5 = f2 / "red-delicious"
     assert isinstance(f5, File)
     assert f5.exists()
+
+
+STORE_INITIAL_CONTENT = {
+    "banana":      123,
+    "cherry":      None,
+    "dragonfruit": True,
+    "elderberry":  "hello",
+    "fig":         [],
+    "guava":       { "a": 123, "b": 456.789, "c": None, "d": { "x": [1, 2, 3], "y": { } } },
+    "icaco":       789.0,
+    "jackfruit":   False
+}
+STORE_YAML_ONLY_CONTENT = {
+    "apple": {
+        "when":    datetime.datetime.utcnow(),
+        "file":    File('does-not-exist.yml')
+    }
+}
+STORE_UPDATES = {
+    "potato": "not a fruit",
+    "tomato": "kinda fruit"
+}
+
+
+def _create_folder_store(content: dict, suffix: str = "yml") -> str:
+    dir = tempfile.TemporaryDirectory()
+    for k, v in content.items():
+        save(str(pathlib.Path(dir.name) / f"{k}.{suffix}"), v)
+    return dir
+
+
+def _dump_folder(folder):
+    print("HISTORY: ")
+    for i, h in enumerate(HISTORY):
+        print(f"{i:-3d}: {h}")
+    p = pathlib.Path(str(folder))
+    print(f"Dump of folder {folder}:")
+    for child in p.iterdir():
+        print(f"  * {child.absolute()}")
+        # with open(child) as filp:
+        #     text = filp.read()
+        for line in  load_txt( str(child.absolute()) ).split("\n"):
+            print(f"    | {line}" )
+
+
+HISTORY = []
+
+
+def _folder_store_checks(content, folder, suffix):  # noqa: F811
+    try:
+        store = FolderStore( folder, suffix=suffix )
+        Li = len(content)
+        Lo = len(store)
+        assert Lo == Li, f"Length of store was {Lo} instead of expected {Li}."
+
+        for k in store.keys():
+            assert k in list(content.keys()), f"Key '{k}' in FolderStore not present in config."
+
+        for k in content.keys():
+            assert k in list(store.keys()), f"Key '{k}' in config not present in FolderStore."
+
+        for k, v in content.items():
+            v2 = store[k]
+            assert v2 == v, f"Store key '{k}' should be {v} but was {v2} instead."
+
+        assert "12345" not in store, "Non-existing key '12345' failed to not be in store."
+
+        assert "cherry" in store, "Existing key 'cherry' failed to be in store."
+
+        del store["banana"]
+        assert "banana" not in store, "Trying to remove key 'banana', but it still exists."
+
+        store["xyz"] = "xyz"
+        xyz = store["xyz"]
+        assert xyz == "xyz", f"Trying to set key 'xyz' to 'xyz', but when accessed later returns '{xyz}'."
+
+        store["xyz"] = "abc"
+        xyz = store["xyz"]
+        assert xyz == "abc", f"Trying to update key 'xyz' to 'abc', but when accessed later returns '{xyz}'."
+
+        store.update(STORE_UPDATES)
+        Li2 = len( STORE_UPDATES ) + Li
+        Lo2 = len( store )
+        assert Lo2 == Li2, f"After updating, length of store was {Lo2} instead of expected {Li2}."
+
+        for k, v in STORE_UPDATES.items():
+            v2 = store[k]
+            assert v2 == v, f"After updating, store key '{k}' should be {v} but was {v2} instead."
+
+        store.clear()
+        Lo3 = len( store )
+        assert Lo3 == 0, f"After clearing, length of store was {Lo3} instead of expected 0."
+    except Exception:
+        print(f"Suffix:   {store.suffix}")
+        print(f"Pattern:  {store.pattern}")
+        print(f"Template: {store.template}")
+        _dump_folder(folder)
+        raise
+
+
+if HAVE_YAML:
+    @pytest.fixture(autouse=True)
+    def sample_yaml_store():
+        content = {}
+        content.update(**STORE_INITIAL_CONTENT)
+        content.update(**STORE_YAML_ONLY_CONTENT)
+        dir = _create_folder_store(content, suffix="yml")
+        print(f"Created: {dir.name}")
+        HISTORY.append(dir.name)
+        yield content, dir.name
+        shutil.rmtree(dir.name)
+        HISTORY.clear()
+        print(f"Destroyed: {dir.name}")
+
+    def test_folder_store_yaml(sample_yaml_store):  # noqa: F811
+        _folder_store_checks( *sample_yaml_store, suffix="yml" )
+
+
+@pytest.fixture(autouse=True)
+def sample_json_store():
+    content = {}
+    content.update(**STORE_INITIAL_CONTENT)
+    dir = _create_folder_store(content, suffix="json")
+    print(f"Created: {dir.name}")
+    HISTORY.append(dir.name)
+    yield content, dir.name
+    shutil.rmtree(dir.name)
+    HISTORY.clear()
+    print(f"Destroyed: {dir.name}")
+
+
+def test_folder_store_json(sample_json_store):  # noqa: F811
+    _folder_store_checks( *sample_json_store, suffix="json" )
